@@ -32,6 +32,13 @@ auto-discover your packages, you would not include "packages" in your
 options.in file at all (whereas with setuptools you would include
 "packages = find:" in your setup.cfg).
 
+(Note that, in addition to the standard setuptools keywords, there are
+a few extra keywords that are used by setuputils itself, either to allow
+simpler inputs that then get expanded into standard format, as with the
+"dev_status" keyword, or to allow you to pass options to setuputils to
+control its behavior, as with the "autodiscover" keyword. These keywords
+are described further in the appropriate function docstrings below.)
+
 Once you have created your .in files, then you simply execute
 
     python3 -m setuputils
@@ -62,7 +69,10 @@ it needs will be in setup.cfg.)
 (Note that extension modules are currently not supported in setup.cfg,
 so you cannot use setuputils in setup.cfg mode if your distribution
 contains any extension modules. You can still use it in "legacy" mode,
-described below.)
+described below. There are some other setuptools keywords that are also
+not supported in setup.cfg and so can only be used in "legacy" mode.
+Setuputils will raise a RuntimeError if you attempt to use it to build
+setup.cfg and any keywords not supported in that mode are present.)
 
 This release of setuputils still supports the "legacy" mode of operation,
 where you include the variables setuputils needs in your setup.py file.
@@ -769,7 +779,7 @@ def make_manifest_in(varmap):
         f.writelines(lines)
 
 
-setuptools_keywords = dict(
+supported_keywords = dict(
     name=str,
     version=str,
     description=str,
@@ -789,7 +799,7 @@ setuptools_keywords = dict(
     scripts=(str, list),
     ext_package=str,
     ext_modules=list,
-    dev_status=str,
+    dev_status=str,  # setuputils keyword
     classifiers=(str, list),
     distclass=type,
     script_name=str,
@@ -801,7 +811,7 @@ setuptools_keywords = dict(
     keywords=(str, list),
     platforms=(str, list),
     cmdclass=dict,
-    data_dirs=list,
+    data_dirs=list,  # setuputils keyword
     data_files=dict,
     package_dir=(str, list),
     package_data=dict,
@@ -819,12 +829,12 @@ setuptools_keywords = dict(
     eager_resources=(str, list),
     dependency_links=(str, list),
     tests_require=(str, list),
-    autodiscover=bool,
+    autodiscover=bool,  # setuputils keyword
     egg_base=str,
 )
 
 list_convert_keywords = tuple(
-    k for k, v in setuptools_keywords.items() if (v is list) or (v == (str, list))
+    k for k, v in supported_keywords.items() if (v is list) or (v == (str, list))
 )
 
 
@@ -837,7 +847,7 @@ def convert_lists(varmap,
     """
     
     for key in list_keys:
-        var_type = setuptools_keywords[key]
+        var_type = supported_keywords[key]
         var = varmap.get(key)
         if var and isinstance(var, str) and ((var_type is list) or ('\n' in var)):
             varmap[key] = var.strip().splitlines()
@@ -884,7 +894,7 @@ def setup_vars(varmap, autodiscover=True, force_manifest_in=False):
     
     return dict(
         (k, v) for k, v in varmap.items()
-        if k in setuptools_keywords
+        if k in supported_keywords
     )
 
 
@@ -951,11 +961,11 @@ setup_cfg_sections = (
         "package_dir",
         "namespace_packages",
         "py_modules",
-        "entry_points",
+        "entry_points",  # for file: entry_points
         "scripts",
     )),
     ("options.extras_require", ()),
-    ("options.entry_points", ()),
+    ("options.entry_points", ()),  # for section entry_points
     ("options.package_data", ()),
     ("options.exclude_package_data", ()),
     ("options.data_files", ()),
@@ -967,6 +977,7 @@ setup_cfg_sections = (
 no_setup_cfg_keys = (
     "ext_package",
     "ext_modules",
+    "distclass",
     "options",
     "cmdclass",
 )
@@ -1007,7 +1018,7 @@ def read_in_lines(lines,
             close_open_key()
             key, value = (s.strip() for s in line.split(sep))
             if value:
-                key_type = setuptools_keywords.get(key, type(value))
+                key_type = supported_keywords.get(key, type(value))
                 if key_type in (list, dict):
                     raise RuntimeError("{} cannot be specified on a single line".format(key))
                 elif (key_type == (str, list)) and listsep not in value:
@@ -1017,7 +1028,7 @@ def read_in_lines(lines,
                 in_vars[key] = value
             else:
                 open_key = key
-                open_type = setuptools_keywords.get(key, list)
+                open_type = supported_keywords.get(key, list)
                 if open_type is dict:
                     raise RuntimeError("Cannot specify extra section tables in .in file.")
                 elif (open_type is not list) and (open_type != (str, list)):
